# pgtree-tui
pgtree is a very useful tool to search for processes and show them in a tree along with their ancestors and descendants. It is great. I had too much processes and wanted to be able to collapse the levels. So I coded this.

This is not directly related to pgtree (other being a similar idea) and contains AI-generated code. 


## Features

* Can use mouse to expand and close
* No stupid F keys like htop and btop
* Can kill process
* Can kill process trees
* Copy pids by clicking on them

## Usage

`pgtree-tui name` 

k to kill
K to kill entire tree
R to refresh

## Alternatives

pgtree and some search
htop and use f keys
use some sort of activity monitor

